# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from payi import Payi, AsyncPayi
from tests.utils import assert_matches_type
from payi.pagination import SyncCursorPage, AsyncCursorPage
from payi.types.use_cases import KpiListResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestKpis:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_update(self, client: Payi) -> None:
        kpi = client.use_cases.kpis.update(
            kpi_name="kpi_name",
            use_case_id="use_case_id",
        )
        assert kpi is None

    @parametrize
    def test_method_update_with_all_params(self, client: Payi) -> None:
        kpi = client.use_cases.kpis.update(
            kpi_name="kpi_name",
            use_case_id="use_case_id",
            score=True,
        )
        assert kpi is None

    @parametrize
    def test_raw_response_update(self, client: Payi) -> None:
        response = client.use_cases.kpis.with_raw_response.update(
            kpi_name="kpi_name",
            use_case_id="use_case_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        kpi = response.parse()
        assert kpi is None

    @parametrize
    def test_streaming_response_update(self, client: Payi) -> None:
        with client.use_cases.kpis.with_streaming_response.update(
            kpi_name="kpi_name",
            use_case_id="use_case_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            kpi = response.parse()
            assert kpi is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update(self, client: Payi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `use_case_id` but received ''"):
            client.use_cases.kpis.with_raw_response.update(
                kpi_name="kpi_name",
                use_case_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `kpi_name` but received ''"):
            client.use_cases.kpis.with_raw_response.update(
                kpi_name="",
                use_case_id="use_case_id",
            )

    @parametrize
    def test_method_list(self, client: Payi) -> None:
        kpi = client.use_cases.kpis.list(
            use_case_id="use_case_id",
        )
        assert_matches_type(SyncCursorPage[KpiListResponse], kpi, path=["response"])

    @parametrize
    def test_method_list_with_all_params(self, client: Payi) -> None:
        kpi = client.use_cases.kpis.list(
            use_case_id="use_case_id",
            cursor="cursor",
            kpi_name="kpi_name",
            limit=0,
            sort_ascending=True,
        )
        assert_matches_type(SyncCursorPage[KpiListResponse], kpi, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Payi) -> None:
        response = client.use_cases.kpis.with_raw_response.list(
            use_case_id="use_case_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        kpi = response.parse()
        assert_matches_type(SyncCursorPage[KpiListResponse], kpi, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Payi) -> None:
        with client.use_cases.kpis.with_streaming_response.list(
            use_case_id="use_case_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            kpi = response.parse()
            assert_matches_type(SyncCursorPage[KpiListResponse], kpi, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: Payi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `use_case_id` but received ''"):
            client.use_cases.kpis.with_raw_response.list(
                use_case_id="",
            )


class TestAsyncKpis:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_update(self, async_client: AsyncPayi) -> None:
        kpi = await async_client.use_cases.kpis.update(
            kpi_name="kpi_name",
            use_case_id="use_case_id",
        )
        assert kpi is None

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncPayi) -> None:
        kpi = await async_client.use_cases.kpis.update(
            kpi_name="kpi_name",
            use_case_id="use_case_id",
            score=True,
        )
        assert kpi is None

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncPayi) -> None:
        response = await async_client.use_cases.kpis.with_raw_response.update(
            kpi_name="kpi_name",
            use_case_id="use_case_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        kpi = await response.parse()
        assert kpi is None

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncPayi) -> None:
        async with async_client.use_cases.kpis.with_streaming_response.update(
            kpi_name="kpi_name",
            use_case_id="use_case_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            kpi = await response.parse()
            assert kpi is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update(self, async_client: AsyncPayi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `use_case_id` but received ''"):
            await async_client.use_cases.kpis.with_raw_response.update(
                kpi_name="kpi_name",
                use_case_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `kpi_name` but received ''"):
            await async_client.use_cases.kpis.with_raw_response.update(
                kpi_name="",
                use_case_id="use_case_id",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncPayi) -> None:
        kpi = await async_client.use_cases.kpis.list(
            use_case_id="use_case_id",
        )
        assert_matches_type(AsyncCursorPage[KpiListResponse], kpi, path=["response"])

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncPayi) -> None:
        kpi = await async_client.use_cases.kpis.list(
            use_case_id="use_case_id",
            cursor="cursor",
            kpi_name="kpi_name",
            limit=0,
            sort_ascending=True,
        )
        assert_matches_type(AsyncCursorPage[KpiListResponse], kpi, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncPayi) -> None:
        response = await async_client.use_cases.kpis.with_raw_response.list(
            use_case_id="use_case_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        kpi = await response.parse()
        assert_matches_type(AsyncCursorPage[KpiListResponse], kpi, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncPayi) -> None:
        async with async_client.use_cases.kpis.with_streaming_response.list(
            use_case_id="use_case_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            kpi = await response.parse()
            assert_matches_type(AsyncCursorPage[KpiListResponse], kpi, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncPayi) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `use_case_id` but received ''"):
            await async_client.use_cases.kpis.with_raw_response.list(
                use_case_id="",
            )
